import click
from .common_func import generate_data as gd
from .common_func import main as m
from .common_func import load_testing_measurements as ms
import os


@click.group()
def main():
    pass

@main.command()
def process_one():
    m.main()

@main.command()
@click.option('--start', default=5)
@click.option('--end', default=22)
@click.option('--step', default=1)
@click.option('--count', default=2)
def generate_data(start: int, end: int, step: int, count: int):
    try:
        os.mkdir('load_testing_data')
    except OSError:
        pass
    gd.generate_data(start, end, step, count)


@main.command()
def measure_time():
    try:
        os.mkdir('load_testing_measurements')
    except OSError:
        pass
    ms.measure_time()


@main.command()
@click.option('--file')
def create_chart(file: str):
    ms.draws_graph(file)


if __name__ =='__main__':
    main()


import random
import os
from math import inf

"""
Функция должна работать по принципу функции range, принимая параметры start, end, step. 
Эти параметры обозначают размеры нагрузочных тестов. 
В дополнении к этому функция должна принимать параметр count - 
сколько разных нагрузочных тестов одного размера нужно сгенерировать. 

Пример использования - generate(start=1, end=22, step=10, count=5) -
генерирует 5 нагрузочных тестов с размером данных 1, 5 нагрузочных тестов с размером данных 11, 5 нагрузочных тестов 
с размером данных 21.

R.D Вы можете сделать кол-вом (которое фигурирует в задании) кол-во вершин в графе, а рёбра рандомно выставлять
"""


# название файлов РАЗМЕР_НОМЕР.РАСШИРЕНИЕ


def generate_data(start: int, end: int, step: int, count: int):
    for i in range(start, end, step):
        for j in range(1, count + 1):
            with open(f'load_testing_data/{i}_{j}.txt', 'w') as file:
                count_of_verts = random.randint(start, i)
                count_of_edges = random.randint(start, end)
                adjacency_matrix = [['inf' for _ in range(count_of_verts)] for _ in range(count_of_verts)]
                for y in range(count_of_edges):
                    vert1 = random.randint(1, count_of_verts)
                    vert2 = random.randint(1, count_of_verts)
                    weight = random.randint(start, end)
                    adjacency_matrix[vert1 - 1][vert2 - 1] = weight

                for q in range(count_of_verts):
                    adjacency_matrix[q][q] = 0

                file.write(str(adjacency_matrix))

                # adjacency_matrix = [[ 0,   3,  inf,  5 ],
                #                     [ 2,   0,  inf,  4 ],
                #                     [inf,  1,   0,  inf],
                #                     [inf, inf,  2,   0 ]]


def main():
    try:
        os.mkdir('load_testing_data')
    except OSError:
        pass

    start = int(input('start: '))
    end = int(input('end: '))
    step = int(input('step: '))
    count = int(input('count: '))

    generate_data(start, end, step, count)


if __name__ == '__main__':
    main()



from math import inf


def input_adjacency_matrix():
    count_of_verts = int(input('Введите количество вершин в графе: '))
    adjacency_matrix = [[inf for _ in range(count_of_verts)] for _ in range(count_of_verts)]
    for i in range(count_of_verts):
        adjacency_matrix[i][i] = 0
    count_of_edges = int(input('Введите количество ребер в графе: '))
    for _ in range(count_of_edges):
        greeting = 'Введите через пробел - номер первой вершины, номер второй вершины, вес ребра: '
        vert1, vert2, weight = map(int, input(greeting).split())
        adjacency_matrix[vert1 - 1][vert2 - 1] = weight
    # adjacency_matrix = [[ 0,   3,  inf,  5 ],
    #                     [ 2,   0,  inf,  4 ],
    #                     [inf,  1,   0,  inf],
    #                     [inf, inf,  2,   0 ]]
    return adjacency_matrix


def floyd_warshall(adjacency_matrix):
    distance = [line.copy() for line in adjacency_matrix]
    verts = list(range(len(adjacency_matrix)))
    pred = [[-1 for _ in verts] for _ in verts]
    for u in verts:
        for neighbor in verts:
            if 0 != adjacency_matrix[u][neighbor] != inf:
                pred[u][neighbor] = u  # ребро u -> neighbor существует
    for k in verts:
        for i in verts:
            for j in verts:
                new_dist = distance[i][k] + distance[k][j]
                if new_dist < distance[i][j]:
                    distance[i][j] = new_dist
                    pred[i][j] = pred[k][j]
    return distance, pred


def path(vert1, vert2, pred_dict):
    path_to_vert = [vert2]
    from_vert = pred_dict[vert2]
    while from_vert != -1:
        path_to_vert = [from_vert] + path_to_vert
        from_vert = pred_dict[from_vert]
    if path_to_vert[0] != vert1:
        return 'Путь отсутствует'
    return ' -> '.join(str(vert + 1) for vert in path_to_vert)


def print_solution(distance, pred):
    print('Кратчайшие пути:')
    for vert1 in range(len(distance)):
        for vert2 in range(len(distance)):
            if vert1 != vert2:
                print(f'{vert1 + 1} -> {vert2 + 1} (вес {distance[vert1][vert2]}):',
                      path(vert1, vert2, pred[vert1]))


def main():
    adjacency_matrix = input_adjacency_matrix()
    print_solution(*floyd_warshall(adjacency_matrix))


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['floyd_warshall_alg', 'floyd_warshall_alg.common_func']

package_data = \
{'': ['*']}

install_requires = \
['Cycler==0.10.0',
 'Pillow==8.2.0',
 'click>=8.0.1,<9.0.0',
 'kiwisolver==1.3.1',
 'matplotlib==3.4.2',
 'numpy==1.20.3',
 'pandas==1.2.4',
 'pyparsing==2.4.7',
 'python-dateutil==2.8.1',
 'pytz==2021.1',
 'six==1.16.0']

entry_points = \
{'console_scripts': ['floyd_alg = floyd_warshall_alg.simple_algorithm:main']}

setup_kwargs = {
    'name': 'floyd-warshall-alg',
    'version': '0.1.2',
    'description': '',
    'long_description': None,
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import os
import time
import csv
import ast
import math
from .main import floyd_warshall
import pandas as pd
import matplotlib.pyplot as plt
# %pylab inline


def avg(numbers: list) -> float:
    return float(sum(numbers)) / max(len(numbers), 1)


def median(lst: list) -> int:
    return sorted(lst)[len(lst) // 2]


def file_correction(lst: list) -> list:
    for q in range(len(lst)):
        for e in range(len(lst[0])):
            if lst[q][e] == 'inf':
                lst[q][e] = math.inf
    return lst


def measure_time():
    test_file = os.listdir(path='load_testing_data/')
    result = []
    mini = math.inf
    maxi = 0.0
    with open(f'load_testing_measurements/{time.time()}.csv', 'w') as file_csv:
        writer = csv.writer(file_csv, delimiter=',')
        writer.writerow(['size', 'min', 'max', 'avg', 'median'])
        for i in sorted(test_file, key=lambda x: int(x[:-4])):
            with open(f'load_testing_data/{i}', 'r') as file:
                lst = file_correction(ast.literal_eval(file.read()))
                start = time.time()
                floyd_warshall([lst])
                end = time.time() - start
                result.append(end)
                maxi = max(maxi, end)
                mini = min(mini, end)
                writer.writerow([i, mini, maxi, avg(result), median(result)])
                print('finish:', i)



def draws_graph(name_file):
    data = pd.read_csv(f"load_testing_measurements/{name_file}.csv")
    data.set_index("size", inplace=True)
    data.head()
    data.plot()
    plt.show()


def main():
    try:
        os.mkdir('load_testing_measurements')
    except OSError:
        pass

    name_file = time.time()

    measure_time()

    # draws_graph(name_file)


if __name__ == "__main__":
    main()
